CREATE OR REPLACE PROCEDURE VALORLIQUIDOCNC(P_ESTABELEC IN NUMBER,
                             P_NRADQ IN NUMBER, 
                             P_PRODUTO IN NUMBER,
                             P_VRBRUTO IN FLOAT,
                             P_TAXA OUT FLOAT,
                             P_VRLIQ OUT FLOAT,
                             P_DTVENDA IN DATE DEFAULT NULL)
AS
   V_RESULT FLOAT;
   V_TXTMP FLOAT;
   V_VRLIQ FLOAT;
BEGIN
   /* FUNO USADA PARA CALCULAR O VALOR LQUIDO DE UMA VENDA, COM BASE NA HIERARQUIA DE TAXAS */
   V_VRLIQ := P_VRBRUTO;
   V_TXTMP := -1;

   /* Verifica a taxa da adquirente para perodos especficos */
   IF P_DTVENDA IS NOT NULL THEN
      BEGIN
         SELECT NVL(VRTAXAADM, -1)
           INTO V_TXTMP
           FROM TAXAPERADQ
          WHERE NRADQUIRENTE = P_NRADQ
            AND P_DTVENDA BETWEEN DTINICIAL AND DTFINAL;
      EXCEPTION
         WHEN NO_DATA_FOUND THEN
            V_TXTMP := -1;
      END;
   END IF;

   /* Verifica a taxa de produto por estabelecimento */
   BEGIN
      SELECT NVL(VRTAXAADM, -1)
        INTO V_TXTMP
        FROM TAXAADQPROD
       WHERE NRPRODUTOADQ = P_PRODUTO
         AND NRADQUIRENTE = P_NRADQ
         AND NRESTABELEC = P_ESTABELEC;
   EXCEPTION
      WHEN NO_DATA_FOUND THEN
         V_TXTMP := -1;
   END;

   IF V_TXTMP = -1 THEN
      /* Verifica a taxa do produto */
      BEGIN
         SELECT NVL(VRTAXAADM, -1)
           INTO V_TXTMP
           FROM TAXAADQPROD
          WHERE NRPRODUTOADQ = P_PRODUTO
            AND NRADQUIRENTE = P_NRADQ
            AND NRESTABELEC IS NULL;
      EXCEPTION
         WHEN NO_DATA_FOUND THEN
            V_TXTMP := -1;
      END;
      IF V_TXTMP = -1 THEN
         /* Verifica a taxa da adquuirente */
         BEGIN
            SELECT NVL(A.VRTAXAADM, -1)
              INTO V_TXTMP
              FROM ADQUIRENTE A
             WHERE NRADQUIRENTE = P_NRADQ;
         EXCEPTION
            WHEN NO_DATA_FOUND THEN
               V_TXTMP := -1;
         END;
      END IF;
   END IF;

   IF V_TXTMP <> -1 THEN
      V_VRLIQ := ROUND(V_VRLIQ - (V_VRLIQ * (V_TXTMP / 100)), 2);
      P_TAXA := V_TXTMP;
   ELSE
      P_TAXA := 0;
   END IF;
   P_VRLIQ := V_VRLIQ;
END;
/

-- VERSAO --
BEGIN ATUVEROBJ('VALORLIQUIDOCNC','6.05.xxx'); END;
/

